@@ -1,10 +1,10 @@
 """This module provides the Admittance class.  This is a generalized
 impedance (s-domain) and converts to other representations.
 
-Copyright 2019 Michael Hayes, UCECE
+Copyright 2019-2020 Michael Hayes, UCECE
 
 """
-
+from __future__ import division
 from .symbols import s
 from .immitance import Immitance
 
@@ -21,6 +21,13 @@ class Admittance(Immitance):
 
     """
 
+    def __rtruediv__(self, x):
+        """Reverse true divide"""
+
+        # TODO: handle Current / Admittance -> Voltage etc.
+        from .impedance import Impedance
+        return Impedance(x / self.expr)
+
     @property
     def Y(self):
         return self    
@@ -38,7 +45,7 @@ class Admittance(Immitance):
         return 1 / self.Yw
 
     def cpt(self):
-        """Create oneport component."""
+        """Create oneport component.  See also network."""        
 
         from .oneport import G, C, L, Y
 
@@ -56,3 +63,14 @@ class Admittance(Immitance):
             return C(y.expr)
 
         return Y(self)    
+
+    def network(self, form='default'):
+        """Synthesise a network with an equivalent admittance.
+        `form` includes: cauerI, cauerII, fosterI, fosterII.
+
+        Note some methods generate networks with negative value
+        components."""
+        
+        return self(s).network(form)
+    
+    
