@@ -11,6 +11,7 @@ from .sym import j, oo, pi, fsym
 from .dsym import nsym, ksym, zsym, dt
 from .acdc import ACChecker, is_dc, is_ac, is_causal
 from .ztransform import ztransform
+from .dft import DFT
 from sympy import Sum, summation, limit
 
 
@@ -27,14 +28,20 @@ class nExpr(seqExpr):
 
     def __init__(self, val, **assumptions):
 
+        check = assumptions.pop('check', True)
+        
         super(nExpr, self).__init__(val, **assumptions)
 
-        #self._fourier_conjugate_class = fExpr
+        self._discrete_fourier_conjugate_class = kExpr
         self._ztransform_conjugate_class = zExpr
 
-        if self.expr.find(zsym) != set():
+        expr = self.expr
+        if check and expr.find(zsym) != set() and not expr.has(Sum):
             raise ValueError(
-                'n-domain expression %s cannot depend on z' % self.expr)
+                'n-domain expression %s cannot depend on z' % expr)
+        if check and expr.find(ksym) != set() and not expr.has(Sum):
+            raise ValueError(
+                'n-domain expression %s cannot depend on k' % expr)            
 
     def infer_assumptions(self):
 
@@ -83,14 +90,14 @@ class nExpr(seqExpr):
         
         return self.__class__(result, **self.assumptions)
 
-    def ztransform(self, **assumptions):
+    def ztransform(self, evaluate=True, **assumptions):
         """Determine one-sided z-transform."""
 
         self.infer_assumptions()
 
         assumptions = self.merge_assumptions(**assumptions)
 
-        result = ztransform(self.expr, self.var, zsym)
+        result = ztransform(self.expr, self.var, zsym, evaluate)
 
         if hasattr(self, '_ztransform_conjugate_class'):
             result = self._ztransform_conjugate_class(result, **assumptions)
@@ -138,20 +145,14 @@ class nExpr(seqExpr):
         from .kexpr import k
 
         if N is None:
-            from .expr import expr
             from .sym import sympify
             
             N = sympify('N')
 
-        foo = self.expr * exp(-2 * j * pi * nsym * ksym / N)
+        result = DFT(self.expr, nsym, ksym, N, evaluate=evaluate)
 
-        if evaluate:
-            result = summation(foo, (nsym, 0, N - 1))
-        else:
-            result = Sum(foo, (nsym, 0, N - 1))
-
-        if hasattr(self, '_fourier_conjugate_class'):
-            result = self._fourier_conjugate_class(result)
+        if hasattr(self, '_discrete_fourier_conjugate_class'):
+            result = self._discrete_fourier_conjugate_class(result)
         else:
             result = kExpr(result, check=False)
             
@@ -184,7 +185,8 @@ class nExpr(seqExpr):
             return self.ZT(**assumptions).DTFT()
 
         from .fexpr import fexpr
-        
+
+        # TODO, handle evaluation keyword
         return fexpr(summation(self.subs(nsym).expr * exp(-2 * j * pi * fsym * nsym * dt), (nsym, -oo, oo)))
 
     def DTFT(self, **assumptions):
@@ -212,7 +214,7 @@ class Yn(nExpr):
 
         super(Yn, self).__init__(val, **assumptions)
         self._ztransform_conjugate_class = Yz
-        self._fourier_conjugate_class = Yk
+        self._discrete_fourier_conjugate_class = Yk
 
 
 class Zn(nExpr):
@@ -225,7 +227,7 @@ class Zn(nExpr):
 
         super(Zn, self).__init__(val, **assumptions)
         self._ztransform_conjugate_class = Zz
-        self._fourier_conjugate_class = Zk
+        self._discrete_fourier_conjugate_class = Zk
 
 
 class Vn(nExpr):
@@ -239,7 +241,7 @@ class Vn(nExpr):
 
         super(Vn, self).__init__(val, **assumptions)
         self._ztransform_conjugate_class = Vz
-        self._fourier_conjugate_class = Vk
+        self._discrete_fourier_conjugate_class = Vk
 
 class In(nExpr):
 
@@ -252,7 +254,7 @@ class In(nExpr):
 
         super(In, self).__init__(val, **assumptions)
         self._ztransform_conjugate_class = Iz
-        self._fourier_conjugate_class = Ik
+        self._discrete_fourier_conjugate_class = Ik
 
 
 class Hn(nExpr):
@@ -266,7 +268,7 @@ class Hn(nExpr):
 
         super(Hn, self).__init__(val, **assumptions)
         self._ztransform_conjugate_class = Hz
-        self._fourier_conjugate_class = Hk
+        self._discrete_fourier_conjugate_class = Hk
 
 def nexpr(arg, **assumptions):
     """Create nExpr object.  If `arg` is nsym return n"""
