@@ -7,6 +7,7 @@ Copyright 2016--2020 Michael Hayes, UCECE
 from __future__ import division
 import sympy as sym
 from sympy.core.mul import _unevaluated_Mul as uMul
+from sympy.core.add import _unevaluated_Add as uAdd
 from .sym import sympify, AppliedUndef
 
 class Pole(object):
@@ -119,7 +120,7 @@ def as_numer_denom_poly(expr, var):
         Dpoly = sym.Poly(D, var)
         Npoly = sym.Poly(N, var)        
     except:
-        D, N = expr.as_numer_denom()
+        N, D = expr.as_numer_denom()
         Dpoly = sym.Poly(D, var)
         Npoly = sym.Poly(N, var)                
         
@@ -217,6 +218,16 @@ def _tc2tf(zeros, poles, K=1, var=None):
     return uMul(K, *(zz + pp))
 
 
+def _pr2tf(poles, residues, var=None):
+    """Create a transfer function from lists of poles and residues.
+
+    """
+    poles = sympify(poles)
+    residues = sympify(residues)
+
+    return uAdd(*[r / (var - p) for r, p in zip(residues, poles)])
+
+
 def as_ratfun_delay(expr, var):
     delay = sym.S.Zero
     
@@ -592,14 +603,11 @@ class Ratfun(object):
         Npoly = sym.Poly(N, var)
         Dpoly = sym.Poly(D, var)
         
-        K = sym.cancel(Npoly.LC() / Dpoly.LC())
-        if delay != 0:
-            K *= sym.exp(self.var * delay)
+        K = Dpoly.EC()
 
-        zeros = sym.roots(Npoly)
-        poles = sym.roots(Dpoly)
-
-        return _tc2tf(zeros, poles, K, self.var) * undef
+        D = D / K
+        N = N / K
+        return sym.Mul(N, sym.Pow(D, -1), evaluate=False) * sym.exp(self.var * delay) * undef
 
     def ZPK(self):
         """Convert to zero-pole-gain (ZPK) form.
