@@ -1,8 +1,15 @@
+from numpy import ndarray
+from .expr import expr
 from .sequence import Sequence
 from .nexpr import n
 
-def seq(s):
+def seq(arg):
 
+    if isinstance(arg, (tuple, list, ndarray)):
+        nv = list(range(len(arg)))
+        return Sequence(arg, nv, var=n)        
+
+    s = arg
     if s.startswith('{'):
         if not s.endswith('}'):
             raise ValueError('Mismatched braces for %s' % s)
@@ -18,13 +25,8 @@ def seq(s):
                 raise ValueError('Cannot have multiple zero index indicators')
             m0 = m
             item = item[1:]
-        try:
-            val = int(item)
-        except ValueError:
-            try:
-                val = float(item)
-            except ValueError:
-                val = complex(item)
+
+        val = expr(item)
         vals.append(val)
 
     if m0 is None:
